@@ -19,6 +19,7 @@ class DjangoCloudTasksAppConfig(AppConfig):
         self.subscriber_tasks = {}
         self.domain = self._fetch_config(name='GOOGLE_CLOUD_TASKS_ENDPOINT', default='http://localhost:8080')
         self.app_name = self._fetch_config(name='GOOGLE_CLOUD_TASKS_APP_NAME', default=os.environ.get('APP_NAME', None))
+        self.delimiter = self._fetch_config(name='GOOGLE_CLOUD_TASKS_DELIMITER', default='--')
 
     def _fetch_config(self, name, default):
         return getattr(settings, name, os.environ.get(name, default))
@@ -40,16 +41,17 @@ class DjangoCloudTasksAppConfig(AppConfig):
         updated = []
         removed = []
         for task_name, task_klass in self.periodic_tasks.items():
-            task_klass().delay()
-            updated.append(task_name)
+            task = task_klass()
+            task.delay()
+            updated.append(task.schedule_name)
 
         if self.app_name:
             client = CloudScheduler()
             for job in client.list(prefix=self.app_name):
-                task_name = job.name.split('/jobs/')[-1]
-                if task_name not in updated:
-                    client.delete(name=task_name)
-                    removed.append(task_name)
+                schedule_name = job.name.split('/jobs/')[-1]
+                if schedule_name not in updated:
+                    asyncio.run(client.delete(name=schedule_name))
+                    removed.append(schedule_name)
 
         return updated, removed
 
@@ -63,4 +65,5 @@ class DjangoCloudTasksAppConfig(AppConfig):
         for task_name, task_klass in self.subscriber_tasks.items():
             task_klass().delay()
             report.append(task_name)
+        # TODO: detect obsolete subscriptions (and publisher topics?)
         return report
